==> openshift-client-4.13.2-sources.jar: io/fabric8/openshift/client/handlers/KubeSchedulerHandler.java <==

                            

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.KubeSchedulerOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.operator.v1.KubeScheduler;
import io.fabric8.openshift.api.model.operator.v1.KubeSchedulerBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class KubeSchedulerHandler implements ResourceHandler<KubeScheduler, KubeSchedulerBuilder> {

  @Override
  public String getKind() {
    return KubeScheduler.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "operator.openshift.io/v1";
    }

  @Override
  public KubeScheduler create(OkHttpClient client, Config config, String namespace, KubeScheduler item) {
    return new KubeSchedulerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public KubeScheduler replace(OkHttpClient client, Config config, String namespace, KubeScheduler item) {
    return new KubeSchedulerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public KubeScheduler reload(OkHttpClient client, Config config, String namespace, KubeScheduler item) {
    return new KubeSchedulerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public KubeSchedulerBuilder edit(KubeScheduler item) {
    return new KubeSchedulerBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, KubeScheduler item) {
    return new KubeSchedulerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).withPropagationPolicy(propagationPolicy).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, KubeScheduler item, Watcher<KubeScheduler> watcher) {
    return new KubeSchedulerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, KubeScheduler item, String resourceVersion, Watcher<KubeScheduler> watcher) {
    return new KubeSchedulerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, KubeScheduler item, ListOptions options, Watcher<KubeScheduler> watcher) {
  return new KubeSchedulerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public KubeScheduler waitUntilReady(OkHttpClient client, Config config, String namespace, KubeScheduler item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new KubeSchedulerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public KubeScheduler waitUntilCondition(OkHttpClient client, Config config, String namespace, KubeScheduler item, Predicate<KubeScheduler> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new KubeSchedulerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> openshift-client-5.2.1-sources.jar: io/fabric8/openshift/client/handlers/KubeSchedulerHandler.java <==

                            

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.KubeSchedulerOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.operator.v1.KubeScheduler;
import io.fabric8.openshift.api.model.operator.v1.KubeSchedulerBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class KubeSchedulerHandler implements ResourceHandler<KubeScheduler, KubeSchedulerBuilder> {

  @Override
  public String getKind() {
    return KubeScheduler.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "operator.openshift.io/v1";
    }

  @Override
  public KubeScheduler create(OkHttpClient client, Config config, String namespace, KubeScheduler item, boolean dryRun) {
    return new KubeSchedulerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).dryRun(dryRun).create();
  }

  @Override
  public KubeScheduler replace(OkHttpClient client, Config config, String namespace, KubeScheduler item, boolean dryRun) {
    return new KubeSchedulerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).dryRun(dryRun).replace(item);
  }

  @Override
  public KubeScheduler reload(OkHttpClient client, Config config, String namespace, KubeScheduler item) {
    return new KubeSchedulerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public KubeSchedulerBuilder edit(KubeScheduler item) {
    return new KubeSchedulerBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, long gracePeriodSeconds, KubeScheduler item, boolean dryRun) {
    return new KubeSchedulerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).dryRun(dryRun).withPropagationPolicy(propagationPolicy).withGracePeriod(gracePeriodSeconds).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, KubeScheduler item, Watcher<KubeScheduler> watcher) {
    return new KubeSchedulerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, KubeScheduler item, String resourceVersion, Watcher<KubeScheduler> watcher) {
    return new KubeSchedulerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, KubeScheduler item, ListOptions options, Watcher<KubeScheduler> watcher) {
  return new KubeSchedulerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public KubeScheduler waitUntilReady(OkHttpClient client, Config config, String namespace, KubeScheduler item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new KubeSchedulerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public KubeScheduler waitUntilCondition(OkHttpClient client, Config config, String namespace, KubeScheduler item, Predicate<KubeScheduler> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new KubeSchedulerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}
